# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from alibabacloud_appstream_center20210901 import models as main_models
from darabonba.model import DaraModel

class CreateAppInstanceGroupResponseBody(DaraModel):
    def __init__(
        self,
        app_instance_group_model: main_models.CreateAppInstanceGroupResponseBodyAppInstanceGroupModel = None,
        request_id: str = None,
    ):
        # The delivery group.
        self.app_instance_group_model = app_instance_group_model
        # The request ID.
        self.request_id = request_id

    def validate(self):
        if self.app_instance_group_model:
            self.app_instance_group_model.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.app_instance_group_model is not None:
            result['AppInstanceGroupModel'] = self.app_instance_group_model.to_map()

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AppInstanceGroupModel') is not None:
            temp_model = main_models.CreateAppInstanceGroupResponseBodyAppInstanceGroupModel()
            self.app_instance_group_model = temp_model.from_map(m.get('AppInstanceGroupModel'))

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        return self

class CreateAppInstanceGroupResponseBodyAppInstanceGroupModel(DaraModel):
    def __init__(
        self,
        app_instance_group_id: str = None,
        node_pool_id: str = None,
        order_id: str = None,
    ):
        # The ID of the delivery group.
        self.app_instance_group_id = app_instance_group_id
        # The ID of the resource group. This parameter is returned if a resource group was created.
        self.node_pool_id = node_pool_id
        # The order ID.
        self.order_id = order_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.app_instance_group_id is not None:
            result['AppInstanceGroupId'] = self.app_instance_group_id

        if self.node_pool_id is not None:
            result['NodePoolId'] = self.node_pool_id

        if self.order_id is not None:
            result['OrderId'] = self.order_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AppInstanceGroupId') is not None:
            self.app_instance_group_id = m.get('AppInstanceGroupId')

        if m.get('NodePoolId') is not None:
            self.node_pool_id = m.get('NodePoolId')

        if m.get('OrderId') is not None:
            self.order_id = m.get('OrderId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_appstream_center20210901 import models as main_models
from darabonba.model import DaraModel

class ListRegionsResponseBody(DaraModel):
    def __init__(
        self,
        region_models: List[main_models.ListRegionsResponseBodyRegionModels] = None,
        request_id: str = None,
    ):
        # The region IDs.
        self.region_models = region_models
        # The request ID.
        self.request_id = request_id

    def validate(self):
        if self.region_models:
            for v1 in self.region_models:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['RegionModels'] = []
        if self.region_models is not None:
            for k1 in self.region_models:
                result['RegionModels'].append(k1.to_map() if k1 else None)

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.region_models = []
        if m.get('RegionModels') is not None:
            for k1 in m.get('RegionModels'):
                temp_model = main_models.ListRegionsResponseBodyRegionModels()
                self.region_models.append(temp_model.from_map(k1))

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        return self

class ListRegionsResponseBodyRegionModels(DaraModel):
    def __init__(
        self,
        region_id: str = None,
    ):
        # The region ID.
        self.region_id = region_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.region_id is not None:
            result['regionId'] = self.region_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('regionId') is not None:
            self.region_id = m.get('regionId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class ModifyAppPolicyShrinkRequest(DaraModel):
    def __init__(
        self,
        app_policy_id: str = None,
        product_type: str = None,
        video_policy_shrink: str = None,
    ):
        # The policy ID.
        # 
        # This parameter is required.
        self.app_policy_id = app_policy_id
        # The product type.
        # 
        # Enumerated values:
        # 
        # *   CloudApp: RDS Cloud App
        # 
        # This parameter is required.
        self.product_type = product_type
        # Displays the policy.
        self.video_policy_shrink = video_policy_shrink

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.app_policy_id is not None:
            result['AppPolicyId'] = self.app_policy_id

        if self.product_type is not None:
            result['ProductType'] = self.product_type

        if self.video_policy_shrink is not None:
            result['VideoPolicy'] = self.video_policy_shrink

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AppPolicyId') is not None:
            self.app_policy_id = m.get('AppPolicyId')

        if m.get('ProductType') is not None:
            self.product_type = m.get('ProductType')

        if m.get('VideoPolicy') is not None:
            self.video_policy_shrink = m.get('VideoPolicy')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class ModifyTenantConfigRequest(DaraModel):
    def __init__(
        self,
        app_instance_group_expire_remind: bool = None,
    ):
        # Specifies whether to enable the resource expiration reminder feature.
        # 
        # Valid values:
        # 
        # *   true
        # *   false
        self.app_instance_group_expire_remind = app_instance_group_expire_remind

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.app_instance_group_expire_remind is not None:
            result['AppInstanceGroupExpireRemind'] = self.app_instance_group_expire_remind

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AppInstanceGroupExpireRemind') is not None:
            self.app_instance_group_expire_remind = m.get('AppInstanceGroupExpireRemind')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_appstream_center20210901 import models as main_models
from darabonba.model import DaraModel

class ListImageRequest(DaraModel):
    def __init__(
        self,
        biz_region_id_list: List[str] = None,
        biz_type: int = None,
        biz_type_list: List[int] = None,
        feature_list: List[str] = None,
        fota_version: str = None,
        image_id: str = None,
        image_name: str = None,
        image_type: str = None,
        language_type: str = None,
        os_type: str = None,
        package_type: str = None,
        page_number: int = None,
        page_size: int = None,
        platform_name: str = None,
        platform_name_list: List[str] = None,
        product_type: str = None,
        product_type_list: List[str] = None,
        protocol_type: str = None,
        resource_instance_type: str = None,
        status: str = None,
        tag_list: List[main_models.ListImageRequestTagList] = None,
    ):
        # The regions that are supported. The EDS images are centralized. Use this parameter to query the regions where the image is deployed.
        self.biz_region_id_list = biz_region_id_list
        # The service type. This parameter is not available publicly.
        # 
        # Valid value:
        # 
        # *   1 (default)
        self.biz_type = biz_type
        # The list of all service types. It is not available publicly.
        self.biz_type_list = biz_type_list
        # The features supported by the image.
        self.feature_list = feature_list
        # The image version.
        self.fota_version = fota_version
        # The image ID.
        self.image_id = image_id
        # The image name. Fuzzy match is supported.
        self.image_name = image_name
        # The type of the images.
        # 
        # Valid values:
        # 
        # *   User: a custom image.
        # *   Shared: a shared image.
        # *   System: a system image.
        # *   Community: a community image.
        self.image_type = image_type
        # The language.
        # 
        # Valid values:
        # 
        # *   en-US: English.
        # *   zh-HK: Chinese, Traditional (Hong Kong, China).
        # *   zh-CN: Simplified Chinese.
        # *   ja-JP: Japanese.
        self.language_type = language_type
        # The OS type of the image.
        # 
        # Valid values:
        # 
        # *   Linux
        # *   Unknown
        # *   Windows
        # *   Android
        self.os_type = os_type
        # The image encapsulation type.
        # 
        # Valid values:
        # 
        # *   Ecs_Container: ECS and Docker image
        # *   Ecs: ECS image
        self.package_type = package_type
        # The current page number.
        self.page_number = page_number
        # The number of entries per page. Maximum value: 100. Default value: 10.
        self.page_size = page_size
        # The name of the operating system platform.
        # 
        # Valid values:
        # 
        # *   Ubuntu
        # *   Debian
        # *   Windows Server 2022
        # *   Windows Server 2019
        # *   Windows Server 2016
        # *   Windows 11
        # *   Windows 10
        self.platform_name = platform_name
        # The list of supported platform types. For valid values, refer to PlatformName above.
        self.platform_name_list = platform_name_list
        # The product type.
        # 
        # Valid values:
        # 
        # *   CloudDesktop: Elastic Desktop Service
        # *   CloudApp: App Streaming
        # *   WuyingServer: Workstation
        self.product_type = product_type
        # The list of products that are supported when the image supports multiple products.
        self.product_type_list = product_type_list
        # The protocol type of the image.
        # 
        # Valid values:
        # 
        # *   HDX: the High-definition Experience (HDX) protocol
        # *   ASP: the Alibaba Cloud-developed ASP protocol
        self.protocol_type = protocol_type
        # Find images with certain fixed specifications.
        self.resource_instance_type = resource_instance_type
        # The status of the image. You can query images in the specified status. By default, all images in the Not Deleted state are queried.
        # 
        # Valid values:
        # 
        # *   AVAILABLE: The image is available.
        # *   INIT: The image is being initialized.
        # *   CREATE_FAILED: The image failed to be created.
        # *   CREATING: The image is being created.
        self.status = status
        # The tags to query.
        self.tag_list = tag_list

    def validate(self):
        if self.tag_list:
            for v1 in self.tag_list:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.biz_region_id_list is not None:
            result['BizRegionIdList'] = self.biz_region_id_list

        if self.biz_type is not None:
            result['BizType'] = self.biz_type

        if self.biz_type_list is not None:
            result['BizTypeList'] = self.biz_type_list

        if self.feature_list is not None:
            result['FeatureList'] = self.feature_list

        if self.fota_version is not None:
            result['FotaVersion'] = self.fota_version

        if self.image_id is not None:
            result['ImageId'] = self.image_id

        if self.image_name is not None:
            result['ImageName'] = self.image_name

        if self.image_type is not None:
            result['ImageType'] = self.image_type

        if self.language_type is not None:
            result['LanguageType'] = self.language_type

        if self.os_type is not None:
            result['OsType'] = self.os_type

        if self.package_type is not None:
            result['PackageType'] = self.package_type

        if self.page_number is not None:
            result['PageNumber'] = self.page_number

        if self.page_size is not None:
            result['PageSize'] = self.page_size

        if self.platform_name is not None:
            result['PlatformName'] = self.platform_name

        if self.platform_name_list is not None:
            result['PlatformNameList'] = self.platform_name_list

        if self.product_type is not None:
            result['ProductType'] = self.product_type

        if self.product_type_list is not None:
            result['ProductTypeList'] = self.product_type_list

        if self.protocol_type is not None:
            result['ProtocolType'] = self.protocol_type

        if self.resource_instance_type is not None:
            result['ResourceInstanceType'] = self.resource_instance_type

        if self.status is not None:
            result['Status'] = self.status

        result['TagList'] = []
        if self.tag_list is not None:
            for k1 in self.tag_list:
                result['TagList'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('BizRegionIdList') is not None:
            self.biz_region_id_list = m.get('BizRegionIdList')

        if m.get('BizType') is not None:
            self.biz_type = m.get('BizType')

        if m.get('BizTypeList') is not None:
            self.biz_type_list = m.get('BizTypeList')

        if m.get('FeatureList') is not None:
            self.feature_list = m.get('FeatureList')

        if m.get('FotaVersion') is not None:
            self.fota_version = m.get('FotaVersion')

        if m.get('ImageId') is not None:
            self.image_id = m.get('ImageId')

        if m.get('ImageName') is not None:
            self.image_name = m.get('ImageName')

        if m.get('ImageType') is not None:
            self.image_type = m.get('ImageType')

        if m.get('LanguageType') is not None:
            self.language_type = m.get('LanguageType')

        if m.get('OsType') is not None:
            self.os_type = m.get('OsType')

        if m.get('PackageType') is not None:
            self.package_type = m.get('PackageType')

        if m.get('PageNumber') is not None:
            self.page_number = m.get('PageNumber')

        if m.get('PageSize') is not None:
            self.page_size = m.get('PageSize')

        if m.get('PlatformName') is not None:
            self.platform_name = m.get('PlatformName')

        if m.get('PlatformNameList') is not None:
            self.platform_name_list = m.get('PlatformNameList')

        if m.get('ProductType') is not None:
            self.product_type = m.get('ProductType')

        if m.get('ProductTypeList') is not None:
            self.product_type_list = m.get('ProductTypeList')

        if m.get('ProtocolType') is not None:
            self.protocol_type = m.get('ProtocolType')

        if m.get('ResourceInstanceType') is not None:
            self.resource_instance_type = m.get('ResourceInstanceType')

        if m.get('Status') is not None:
            self.status = m.get('Status')

        self.tag_list = []
        if m.get('TagList') is not None:
            for k1 in m.get('TagList'):
                temp_model = main_models.ListImageRequestTagList()
                self.tag_list.append(temp_model.from_map(k1))

        return self

class ListImageRequestTagList(DaraModel):
    def __init__(
        self,
        key: str = None,
        value: str = None,
    ):
        # The key of the custom tag.
        self.key = key
        # The value of the custom tag.
        self.value = value

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.key is not None:
            result['Key'] = self.key

        if self.value is not None:
            result['Value'] = self.value

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Key') is not None:
            self.key = m.get('Key')

        if m.get('Value') is not None:
            self.value = m.get('Value')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from alibabacloud_appstream_center20210901 import models as main_models
from darabonba.model import DaraModel

class ModifyNodePoolAmountResponseBody(DaraModel):
    def __init__(
        self,
        data: main_models.ModifyNodePoolAmountResponseBodyData = None,
        request_id: str = None,
    ):
        # The returned data.
        self.data = data
        # The request ID.
        self.request_id = request_id

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Data') is not None:
            temp_model = main_models.ModifyNodePoolAmountResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        return self

class ModifyNodePoolAmountResponseBodyData(DaraModel):
    def __init__(
        self,
        order_id: str = None,
    ):
        # The order ID.
        self.order_id = order_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.order_id is not None:
            result['OrderId'] = self.order_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('OrderId') is not None:
            self.order_id = m.get('OrderId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_appstream_center20210901 import models as main_models
from darabonba.model import DaraModel

class DeleteAppInstancesResponseBody(DaraModel):
    def __init__(
        self,
        delete_app_instance_models: List[main_models.DeleteAppInstancesResponseBodyDeleteAppInstanceModels] = None,
        request_id: str = None,
    ):
        # The data returned.
        self.delete_app_instance_models = delete_app_instance_models
        # The request ID.
        self.request_id = request_id

    def validate(self):
        if self.delete_app_instance_models:
            for v1 in self.delete_app_instance_models:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['DeleteAppInstanceModels'] = []
        if self.delete_app_instance_models is not None:
            for k1 in self.delete_app_instance_models:
                result['DeleteAppInstanceModels'].append(k1.to_map() if k1 else None)

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.delete_app_instance_models = []
        if m.get('DeleteAppInstanceModels') is not None:
            for k1 in m.get('DeleteAppInstanceModels'):
                temp_model = main_models.DeleteAppInstancesResponseBodyDeleteAppInstanceModels()
                self.delete_app_instance_models.append(temp_model.from_map(k1))

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        return self

class DeleteAppInstancesResponseBodyDeleteAppInstanceModels(DaraModel):
    def __init__(
        self,
        app_instance_id: str = None,
        code: str = None,
        message: str = None,
        success: bool = None,
    ):
        # The ID of the application instance.
        self.app_instance_id = app_instance_id
        # The error code.
        self.code = code
        # The error message.
        self.message = message
        # Specifies whether the application instance is deleted.
        # 
        # Valid values:
        # 
        # *   true
        # *   false
        self.success = success

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.app_instance_id is not None:
            result['AppInstanceId'] = self.app_instance_id

        if self.code is not None:
            result['Code'] = self.code

        if self.message is not None:
            result['Message'] = self.message

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AppInstanceId') is not None:
            self.app_instance_id = m.get('AppInstanceId')

        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from darabonba.model import DaraModel

class ListBindInfoRequest(DaraModel):
    def __init__(
        self,
        app_id_list: List[str] = None,
        app_instance_group_id_list: List[str] = None,
        app_instance_id_list: List[str] = None,
        page_number: int = None,
        page_size: int = None,
        user_id_list: List[str] = None,
        wy_id_list: List[str] = None,
    ):
        # The app IDs. You can specify 1 to 100 IDs.
        # 
        # >  If you specify this parameter, only the bindings of the specified apps are returned.
        self.app_id_list = app_id_list
        # The IDs of the delivery groups. You can specify 1 to 100 IDs.
        # 
        # >  If you specify this parameter, only the bindings of the specified delivery groups are returned.
        self.app_instance_group_id_list = app_instance_group_id_list
        # The IDs of app instances. You can specify 1 to 100 IDs.
        # 
        # >  If you specify this parameter, only the bindings of the specified app instances are returned.
        self.app_instance_id_list = app_instance_id_list
        # The page number. Default value: `1`. We recommend that you specify this parameter.
        self.page_number = page_number
        # The number of entries per page. The value cannot be greater than `100`. Default value: `20`. We recommend that you specify this parameter.
        self.page_size = page_size
        # The user IDs. You can specify 1 to 100 IDs.
        # 
        # >  If you specify this parameter, only the bindings of the specified users are returned.
        self.user_id_list = user_id_list
        # The IDs of the Alibaba Cloud Workspace users. You can specify 1 to 100 IDs.
        # 
        # >  If you specify this parameter, only the bindings of the specified Alibaba Cloud Workspace users are returned.
        self.wy_id_list = wy_id_list

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.app_id_list is not None:
            result['AppIdList'] = self.app_id_list

        if self.app_instance_group_id_list is not None:
            result['AppInstanceGroupIdList'] = self.app_instance_group_id_list

        if self.app_instance_id_list is not None:
            result['AppInstanceIdList'] = self.app_instance_id_list

        if self.page_number is not None:
            result['PageNumber'] = self.page_number

        if self.page_size is not None:
            result['PageSize'] = self.page_size

        if self.user_id_list is not None:
            result['UserIdList'] = self.user_id_list

        if self.wy_id_list is not None:
            result['WyIdList'] = self.wy_id_list

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AppIdList') is not None:
            self.app_id_list = m.get('AppIdList')

        if m.get('AppInstanceGroupIdList') is not None:
            self.app_instance_group_id_list = m.get('AppInstanceGroupIdList')

        if m.get('AppInstanceIdList') is not None:
            self.app_instance_id_list = m.get('AppInstanceIdList')

        if m.get('PageNumber') is not None:
            self.page_number = m.get('PageNumber')

        if m.get('PageSize') is not None:
            self.page_size = m.get('PageSize')

        if m.get('UserIdList') is not None:
            self.user_id_list = m.get('UserIdList')

        if m.get('WyIdList') is not None:
            self.wy_id_list = m.get('WyIdList')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class CreateImageByInstanceRequest(DaraModel):
    def __init__(
        self,
        auto_clean_userdata: bool = None,
        biz_type: int = None,
        description: str = None,
        disk_type: str = None,
        image_name: str = None,
        instance_id: str = None,
        instance_type: str = None,
        product_type: str = None,
        sub_instance_id: str = None,
    ):
        # This parameter is applicable only to scenarios in which the instance type is Cloud Desktop. Specifies whether to clear private data of users. If this parameter is set to true, the created image clears data in directories other than Administrator and Public in the C:\\Users directory.
        # 
        # Valid values:
        # 
        # *   true: cleanup.
        # *   false: does not clear.
        self.auto_clean_userdata = auto_clean_userdata
        # This parameter is not publicly available.
        self.biz_type = biz_type
        # The description of the image.
        self.description = description
        # The type of disk data contained in the image. By default, the system disk and data disk of the instance are included.
        # 
        # Valid values:
        # 
        # *   SYSTEM: only system disk.
        # *   ALL: system disk + data disk
        self.disk_type = disk_type
        # The name of the image.
        self.image_name = image_name
        # The ID of the RDS instance. The instance can be a CloudDesktop instance, a workstation instance. To ensure data consistency in the image, we recommend that you shut down the instance before you create an image.
        self.instance_id = instance_id
        # The instance type.
        # 
        # Valid values:
        # 
        # *   CloudDesktop: Cloud Desktop.
        # *   WuyingServer: Workstation
        self.instance_type = instance_type
        # This parameter is not publicly available.
        self.product_type = product_type
        # The ID of the child instance. This parameter is not used in cloud computing scenarios. Workstation scenarios, you need to specify a persistent session ID to ensure that a specific instance is located.
        self.sub_instance_id = sub_instance_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.auto_clean_userdata is not None:
            result['AutoCleanUserdata'] = self.auto_clean_userdata

        if self.biz_type is not None:
            result['BizType'] = self.biz_type

        if self.description is not None:
            result['Description'] = self.description

        if self.disk_type is not None:
            result['DiskType'] = self.disk_type

        if self.image_name is not None:
            result['ImageName'] = self.image_name

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.instance_type is not None:
            result['InstanceType'] = self.instance_type

        if self.product_type is not None:
            result['ProductType'] = self.product_type

        if self.sub_instance_id is not None:
            result['SubInstanceId'] = self.sub_instance_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AutoCleanUserdata') is not None:
            self.auto_clean_userdata = m.get('AutoCleanUserdata')

        if m.get('BizType') is not None:
            self.biz_type = m.get('BizType')

        if m.get('Description') is not None:
            self.description = m.get('Description')

        if m.get('DiskType') is not None:
            self.disk_type = m.get('DiskType')

        if m.get('ImageName') is not None:
            self.image_name = m.get('ImageName')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('InstanceType') is not None:
            self.instance_type = m.get('InstanceType')

        if m.get('ProductType') is not None:
            self.product_type = m.get('ProductType')

        if m.get('SubInstanceId') is not None:
            self.sub_instance_id = m.get('SubInstanceId')

        return self

